@@ -13,9 +13,7 @@
 # 导入核心功能
 from .core import (
     BaseAI, Config, registry, ai_plugin, 
-    DynamicLqcodeAI, LqcodeAI, lq,
-    PoetryResult, WeatherResult, BilibiliResult, 
-    IdiomsResult, SnackPropsResult, WeaponResult, JokeResult
+    DynamicLqcodeAI, LqcodeAI, lq
 )
 
 # 自动导入所有插件（这会触发插件注册）
@@ -52,15 +50,6 @@ __all__ = [
     'LqcodeAI',
     'DynamicLqcodeAI',
     
-    # 类型定义
-    'PoetryResult', 
-    'WeatherResult', 
-    'BilibiliResult', 
-    'IdiomsResult', 
-    'SnackPropsResult', 
-    'WeaponResult',
-    'JokeResult',
-    
     # AI插件类（动态生成）
     *_plugin_classes,
     
